### 严格推导过程（修正用户对白噪声的理解）

您提出的疑问非常关键。让我们重新梳理这个推导过程，特别注意白噪声项的处理。

---

#### **1. 模型设定**
AR(1)模型定义为：
$$
z_t = \rho z_{t-1} + \varepsilon_t
$$
其中：
- $\varepsilon_t \sim \text{WN}(0, \sigma_\varepsilon^2)$ 是白噪声（独立同分布）
- $|\rho| < 1$ 保证平稳性

---

#### **2. 递推展开（关键步骤）**
通过无限递推将 $z_t$ 表示为历史噪声的线性组合：
$$
\begin{aligned}
z_t &= \varepsilon_t + \rho z_{t-1} \\
&= \varepsilon_t + \rho (\varepsilon_{t-1} + \rho z_{t-2}) \\
&= \varepsilon_t + \rho \varepsilon_{t-1} + \rho^2 \varepsilon_{t-2} + \cdots \\
&= \sum_{j=0}^\infty \rho^j \varepsilon_{t-j}
\end{aligned}
$$

**为什么需要 $\varepsilon_{t-j}$？**  
虽然所有 $\varepsilon_{t-j}$ 的方差都是 $\sigma_\varepsilon^2$，但它们是**不同时刻**的独立随机变量。不能合并为一个 $\varepsilon$，因为：
- 每个时间点 $t-j$ 的噪声 $\varepsilon_{t-j}$ 是独立的新信息
- 合并会丢失时间维度信息，破坏模型结构

---

#### **3. 方差计算（严格推导）**
利用方差的性质（独立变量线性组合的方差）：
$$
\text{Var}(z_t) = \text{Var}\left( \sum_{j=0}^\infty \rho^j \varepsilon_{t-j} \right)
$$

**步骤分解：**
1. **独立性**：$\varepsilon_{t-j}$ 相互独立 ⇒ 方差可加
   $$
   = \sum_{j=0}^\infty \text{Var}(\rho^j \varepsilon_{t-j})
   $$
2. **常数提取**：$\rho^j$ 是非随机系数
   $$
   = \sum_{j=0}^\infty \rho^{2j} \text{Var}(\varepsilon_{t-j})
   $$
3. **同方差性**：$\text{Var}(\varepsilon_{t-j}) = \sigma_\varepsilon^2$ 对所有 $j$ 成立
   $$
   = \sigma_\varepsilon^2 \sum_{j=0}^\infty \rho^{2j}
   $$
4. **级数求和**：$|\rho|<1$ 时几何级数收敛
   $$
   = \sigma_\varepsilon^2 \cdot \frac{1}{1-\rho^2} = \frac{\sigma_\varepsilon^2}{1-\rho^2}
   $$

---

#### **4. 为什么不能简化为单一 $\varepsilon$？**
若错误地尝试合并：
$$
\text{错误写法：} \quad z_t \overset{?}{=} \varepsilon_t (1 + \rho + \rho^2 + \cdots) = \frac{\varepsilon_t}{1-\rho}
$$
会导致：
1. **方差计算错误**：
   $$
   \text{Var}(z_t) \overset{?}{=} \frac{\text{Var}(\varepsilon_t)}{(1-\rho)^2} = \frac{\sigma_\varepsilon^2}{(1-\rho)^2}
   $$
   （与正确结果 $\frac{\sigma_\varepsilon^2}{1-\rho^2}$ 不符）
   
2. **物理意义错误**：
   - 忽略了不同时刻噪声的独立性
   - 错误地假设所有历史噪声完全相关

---

#### **5. 结论**
- **正确结果**：
  $$
  \text{Var}(z_t) = \frac{\sigma_\varepsilon^2}{1-\rho^2} \quad \text{（与时间 $t$ 无关）}
  $$
- **核心要点**：
  1. 必须保留 $\varepsilon_{t-j}$ 的下标，表示不同时刻的独立噪声
  2. 几何级数求和时，系数是 $\rho^{2j}$（不是 $\rho^j$），因为方差运算涉及平方

---

### 补充说明
此推导方法是时间序列分析的标准技术（参考Box & Jenkins《Time Series Analysis》）。白噪声的独立性是保证方差可加性的关键，任何简化合并 $\varepsilon_{t-j}$ 的操作都会破坏模型的时间依赖性结构。





根据引理1，$\text{Var}[\lambda_1(A_t)] \approx 2\sigma^2 = \sigma_1^2$。为使模型与理论一致，可设：

$$
\sigma_\varepsilon^2 = (1 - \rho^2) \cdot 2\sigma^2
$$

此时：

$$
\text{Var}[\tilde{z}_t] = 2\sigma^2 = \sigma_1^2
$$